@@ -413,19 +413,13 @@ static BOOL xf_event_VisibilityNotify(xfContext* xfc, const XVisibilityEvent* ev
 	return TRUE;
 }
 
-BOOL xf_generic_MotionNotify(xfContext* xfc, int x, int y, int state, Window window, BOOL app)
+BOOL xf_generic_MotionNotify(xfContext* xfc, int x, int y, Window window, BOOL app)
 {
 	Window childWindow = None;
 
 	WINPR_ASSERT(xfc);
 	WINPR_ASSERT(xfc->common.context.settings);
 
-	if (!freerdp_settings_get_bool(xfc->common.context.settings, FreeRDP_MouseMotion))
-	{
-		if ((state & (Button1Mask | Button2Mask | Button3Mask)) == 0)
-			return TRUE;
-	}
-
 	if (app)
 	{
 		/* make sure window exists */
@@ -442,7 +436,8 @@ BOOL xf_generic_MotionNotify(xfContext* xfc, int x, int y, int state, Window win
 
 	if (xfc->fullscreen && !app)
 	{
-		XSetInputFocus(xfc->display, xfc->window->handle, RevertToPointerRoot, CurrentTime);
+		if (xfc->window)
+			XSetInputFocus(xfc->display, xfc->window->handle, RevertToPointerRoot, CurrentTime);
 	}
 
 	return TRUE;
@@ -473,8 +468,7 @@ static BOOL xf_event_MotionNotify(xfContext* xfc, const XMotionEvent* event, BOO
 	    (xfc->common.mouse_grabbed && freerdp_client_use_relative_mouse_events(&xfc->common)))
 		return TRUE;
 
-	return xf_generic_MotionNotify(xfc, event->x, event->y,
-	                               WINPR_ASSERTING_INT_CAST(int, event->state), event->window, app);
+	return xf_generic_MotionNotify(xfc, event->x, event->y, event->window, app);
 }
 
 BOOL xf_generic_ButtonEvent(xfContext* xfc, int x, int y, int button, Window window, BOOL app,
@@ -582,6 +576,8 @@ static BOOL xf_event_ButtonPress(xfContext* xfc, const XButtonEvent* event, BOOL
 	if (xfc->xi_event ||
 	    (xfc->common.mouse_grabbed && freerdp_client_use_relative_mouse_events(&xfc->common)))
 		return TRUE;
+	if (!app && xfc_is_floatbar_window(xfc, event->window))
+		return TRUE;
 	return xf_generic_ButtonEvent(xfc, event->x, event->y,
 	                              WINPR_ASSERTING_INT_CAST(int, event->button), event->window, app,
 	                              TRUE);
@@ -963,7 +959,7 @@ static BOOL xf_event_PropertyNotify(xfContext* xfc, const XPropertyEvent* event,
 	 * when the window has been minimized, maximized, restored locally
 	 * ie. not using the buttons on the rail window itself
 	 */
-	if (((event->atom == xfc->_NET_WM_STATE) && (event->state != PropertyDelete)) ||
+	if (((event->atom == xfc->NET_WM_STATE) && (event->state != PropertyDelete)) ||
 	    ((event->atom == xfc->WM_STATE) && (event->state != PropertyDelete)))
 	{
 		BOOL status = FALSE;
@@ -982,9 +978,9 @@ static BOOL xf_event_PropertyNotify(xfContext* xfc, const XPropertyEvent* event,
 				return TRUE;
 		}
 
-		if (event->atom == xfc->_NET_WM_STATE)
+		if (event->atom == xfc->NET_WM_STATE)
 		{
-			status = xf_GetWindowProperty(xfc, event->window, xfc->_NET_WM_STATE, 12, &nitems,
+			status = xf_GetWindowProperty(xfc, event->window, xfc->NET_WM_STATE, 12, &nitems,
 			                              &bytes, &prop);
 
 			if (status)
@@ -1331,7 +1327,7 @@ BOOL xf_event_process(freerdp* instance, const XEvent* event)
 	if (!xf_floatbar_check_event(floatbar, event) && !xf_floatbar_is_locked(floatbar))
 		xf_input_handle_event(xfc, event);
 
-	XSync(xfc->display, FALSE);
+	LogDynAndXSync(xfc->log, xfc->display, FALSE);
 	return status;
 }
 
